@@ -1,19 +1,21 @@
 # pylint: disable=missing-docstring,protected-access
 import time
 import threading
+from typing import Optional
 import jwt
 import pytest
 
-from ibm_cloud_sdk_core import JWTTokenManager
+from ibm_cloud_sdk_core import JWTTokenManager, DetailedResponse
 
 class JWTTokenManagerMockImpl(JWTTokenManager):
-    def __init__(self, url=None, access_token=None):
+    def __init__(self, url: Optional[str] = None, access_token: Optional[str] = None) -> None:
         self.url = url
         self.access_token = access_token
         self.request_count = 0 # just for tests to see how  many times request was called
-        super(JWTTokenManagerMockImpl, self).__init__(url, access_token, 'access_token')
+        super().__init__(url, disable_ssl_verification=access_token,
+                         token_name='access_token')
 
-    def request_token(self):
+    def request_token(self) -> DetailedResponse:
         self.request_count += 1
         current_time = int(time.time())
         token_layout = {
@@ -43,7 +45,7 @@ class JWTTokenManagerMockImpl(JWTTokenManager):
         time.sleep(0.5)
         return response
 
-def _get_current_time():
+def _get_current_time() -> int:
     return int(time.time())
 
 def test_get_token():
@@ -81,7 +83,7 @@ def test_paced_get_token():
     assert token_manager.request_count == 1
 
 def test_is_token_expired():
-    token_manager = JWTTokenManagerMockImpl(None, None)
+    token_manager = JWTTokenManagerMockImpl(None, access_token=None)
     assert token_manager._is_token_expired() is True
     token_manager.expire_time = _get_current_time() + 3600
     assert token_manager._is_token_expired() is False
@@ -90,7 +92,7 @@ def test_is_token_expired():
 
 def test_not_implemented_error():
     with pytest.raises(NotImplementedError) as err:
-        token_manager = JWTTokenManager(None, None)
+        token_manager = JWTTokenManager(None, disable_ssl_verification=None)
         token_manager.request_token()
     assert str(err.value) == 'request_token MUST be overridden by a subclass of JWTTokenManager.'
 
